Django-Vitae Documentation — Django-Vitae 0.0.1 documentation

# Django-Vitae Documentation

## Overview

Django-Vitae allows users to make highly customizable curricula vitae for use on their websites. The application provides models for common entries on curricula vitae such as education, employment, publications, teaching, and service. Django-Vitae eliminates many of the repetitive tasks related to producing curricula vitae. The included templates provide a complete CV “out of the box”, but allows researchers who might be interested to customize the format using Django templating language.

## Installation

A stable version of Django-Vitae is available in the Python Package Index and can be installed using `pip`:

    $ pip install django-vitae

The latest development version can be obtained from GitHub:

    $ git clone https://github.com/mikebader/django-vitae
    $ cd django-vitae
    $ python setup.py install

If you do not have experience with Django, you might be interested in the Getting Started guide.

## Organization of the Documentation

- Complete Vitae Views

  > - HTML
  > - PDF

- CV Sections documents the API to write lines on CV by different sections on a CV

  > - Education & Employment
  > - Publications ( Articles | Books | Chapters | Reports)
  > - Other Works ( Grants | Talks | Other Writing | Datasets)
  > - Teaching
  > - Service

- Templates

  > - Template tags & filters
  > - Template structure

- Settings

- Module Reference

## Contributing to Django-Vitae

It’s quite possible that Django-Vitae does not include all types of publications necessary. You may open an issue, or–even better–contribute code for other common types of publications not already incorporated into Django-Vitae.

## Indices and tables

- Index
- Module Index
- Search Page

## Documentation Contents

- Getting Started
- Complete Vitae Views
  - HTML
  - PDF
- CV Sections
  - Publications
    - Common Features
    - Articles
    - Books
    - Chapters
    - Reports
  - Other Works
    - Grants
    - Talks
    - Other Writing
    - Datasets
- Shortcuts
- Settings
  - `CV_PUBLICATION_STATUS_CHOICES`
  - `CV_FILE_TYPES_CHOICES`
  - `CV_STUDENT_LEVELS_CHOICES`
  - `CV_SERVICE_TYPES_CHOICES`
  - `CV_KEY_CONTRIBUTORS_LIST`
- Module Reference
  - `cv.models`
    - Publications
    - Works
    - Base Models
  - `cv.models.managers`
  - `cv.views`